import React, { useRef } from 'react';
import styles from '../styles/Login.module.css';
import { withPublic } from '../src/context/hooks/route';
import Alert from 'react-popup-alert';

function Login({ auth, pathname }: any) {
  const email: any = useRef();
  const password: any = useRef();
  const [alert, setAlert] = React.useState({
    type: 'error',
    text: '',
    show: false
  });

  const {
    signInUserWithEmailAndPassword,
    error
  } = auth;

  const handleLogin = async (e: any) => {
    e.preventDefault();
    await signInUserWithEmailAndPassword(
      email.current.value,
      password.current.value
    );
    if(error?.[pathname]) {
      setAlert({
        type: 'error',
        text: `${error[pathname]}`,
        show: true
      });
    }
  };

  function onCloseAlert() {
    setAlert({
      type: '',
      text: '',
      show: false
    });
  }

  return (
    <>
      <div className={styles.loginpage}>
        <div className={styles.form}>
          <form className={styles.loginform} onSubmit={handleLogin}>
            <Alert
              header={'Error!'}
              btnText={'Close'}
              text={alert.text}
              type={alert.type}
              show={alert.show}
              onClosePress={onCloseAlert}
              pressCloseOnOutsideClick={true}
              showBorderBottom={false}
              alertStyles={{}}
              headerStyles={{}}
              textStyles={{}}
              buttonStyles={{ color: '#20538F', backgroundColor: 'white'}}
            />
            <input type="email" placeholder="email address" ref={email}/>
            <input type="password" placeholder="password" ref={password}/>
            <button>Login</button>
          </form>
        </div>
      </div>
    </>
  );
}

export default withPublic(Login);
