import { useRouter } from 'next/router';
import { createContext, useContext, useState } from 'react';
import { AuthService } from '../../service/AuthService';

const authContext = createContext({} as any);

export default function useAuth() {
  return useContext(authContext);
}

export function AuthProvider(props: any) {
  const [user, setUser] = useState(null);
  const [error, setError] = useState<any>();

  const router = useRouter();
  const pathname: any = router.pathname;

  const handleLogout = async () => {
    await AuthService.logout();
    setUser(null);
  };

  const signInUserWithEmailAndPassword = async (email: string, password: string) => {
    if(email && password) {
      const { err, newUser }: any = await AuthService.signInUserWithEmailAndPassword(
        email,
        password
      );
      if(err) {
        setError({ [pathname]: err });
        return;
      }
      setUser(newUser ?? null);
      router.push('/');
    } else {
      setError({ [pathname]: 'Email and password can not be empty.' });
    }
  };

  const value = {
    user,
    error,
    handleLogout,
    setUser,
    signInUserWithEmailAndPassword
  };

  return <authContext.Provider value={value} {...props} />;
}
